@@ -4,4 +4,4 @@ from ScriptingBridge import SBApplication
 
 iTunes = SBApplication.applicationWithBundleIdentifier_("com.apple.iTunes")
 
-print iTunes.currentTrack().name()
+print(iTunes.currentTrack().name())
